@@ -20,73 +20,65 @@ import inspect
 import json
 import locale
 import os
-import profile
 import re
-import six
 import sys
 import time
-from builtins import input
-from builtins import str
+from builtins import input, str
+from subprocess import PIPE, Popen
 
 import argcomplete
+import six
 import yaml
 from argcomplete.completers import ChoicesCompleter, FilesCompleter
 from ec2_utils import ebs, interface
-from ec2_utils.instance_info import stack_params_and_outputs_and_stack, dthandler
+from ec2_utils.instance_info import dthandler, stack_params_and_outputs_and_stack
 from ec2_utils.logs import CloudWatchLogsThread
 from ec2_utils.utils import best_effort_stacks
-from pygments import highlight, lexers, formatters
+from pygments import formatters, highlight, lexers
 from pygments.styles import get_style_by_name
 from threadlocal_aws import region, regions
 from threadlocal_aws.clients import sso
 
-from n_utils import (
-    aws_infra_util,
-    cf_bootstrap,
-    cf_deploy,
-    utils,
-    _to_bytes,
-    _to_str,
-    connect,
-)
-from n_utils.account_utils import list_created_accounts, create_account
-from n_utils.aws_infra_util import load_parameters, json_save_small, json_load
-from n_utils.cloudfront_utils import (
-    distributions,
-    distribution_comments,
-    upsert_cloudfront_records,
-)
+from n_utils import _to_bytes, _to_str, aws_infra_util, cf_bootstrap, cf_deploy, connect, utils
+from n_utils.account_utils import create_account, list_created_accounts
+from n_utils.aws_infra_util import json_load, json_save_small, load_parameters
+from n_utils.az_util import ensure_group, ensure_management_group, fetch_properties
+from n_utils.cloudfront_utils import distribution_comments, distributions, upsert_cloudfront_records
 from n_utils.ecr_utils import ensure_repo, repo_uri
 from n_utils.git_utils import Git
 from n_utils.log_events import CloudFormationEvents
 from n_utils.maven_utils import add_server
 from n_utils.mfa_utils import (
+    list_mfa_tokens,
     mfa_add_token,
+    mfa_backup_tokens,
+    mfa_decrypt_backup_tokens,
     mfa_delete_token,
     mfa_generate_code,
     mfa_generate_code_with_secret,
-    list_mfa_tokens,
-    mfa_backup_tokens,
-    mfa_decrypt_backup_tokens,
-    mfa_to_qrcode,
     mfa_read_token,
+    mfa_to_qrcode,
 )
-from n_utils.ndt import find_include, find_all_includes, include_dirs
-from n_utils.ndt_project import Project
-from n_utils.ndt_project import list_jobs, list_components, upsert_codebuild_projects
-from n_utils.profile_util import get_profile, read_profiles, read_sso_profile, resolve_profile_type, update_profile, _epoc_to_str
-from n_utils.tf_utils import pull_state, jmespath_var, flat_state
-from n_utils.az_util import fetch_properties
-from n_utils.utils import (
-    session_token,
-    get_images,
-    promote_image,
-    share_to_another_region,
-    interpolate_file,
-    assumed_role_name,
+from n_utils.ndt import find_all_includes, find_include, include_dirs
+from n_utils.ndt_project import Project, list_components, list_jobs, upsert_codebuild_projects
+from n_utils.profile_util import (
+    _epoc_to_str,
+    get_profile,
+    read_profiles,
+    read_sso_profile,
+    resolve_profile_type,
+    update_profile,
 )
-from n_utils.az_util import ensure_group, ensure_management_group
 from n_utils.route53_util import upsert_record
+from n_utils.tf_utils import flat_state, jmespath_var, pull_state
+from n_utils.utils import (
+    assumed_role_name,
+    get_images,
+    interpolate_file,
+    promote_image,
+    session_token,
+    share_to_another_region,
+)
 
 SYS_ENCODING = locale.getpreferredencoding()
 
@@ -285,10 +277,22 @@ def update_stack():
         help="Do not actually deploy anything, but just "
         + "assemble the json and associated parameters",
     )
+    parser.add_argument(
+        "-r",
+        "--disable-rollback",
+        action="store_true",
+        help="Disable stack rollback on failure",
+    )
     args = parser.parse_args()
     if not os.path.isfile(args.yaml_template):
         parser.error(args.yaml_template + " not found")
-    cf_deploy.deploy(args.stack_name, args.yaml_template, args.region, args.dry_run)
+    cf_deploy.deploy(
+        args.stack_name,
+        args.yaml_template,
+        args.region,
+        args.dry_run,
+        disable_rollback=args.disable_rollback,
+    )
     return
 
 
@@ -1046,14 +1050,27 @@ def cli_load_parameters():
     filter_arr = []
     if args.filter:
         filter_arr = args.filter.split(",")
+        filter_types = {}
+        for filter_entry in filter_arr.copy():
+            if len(filter_entry.split(":")) > 1:
+                filter_arr = list(map(lambda x: x.replace(filter_entry, filter_entry.split(":")[0]), filter_arr))
+                filter_types[filter_entry.split(":")[0]] = filter_entry.split(":")[1]
     del args.filter
     parameters = load_parameters(**vars(args))
     if filter_arr:
         for param_key in set(parameters.keys()):
             if param_key not in filter_arr:
                 del parameters[param_key]
+            elif param_key in filter_types:
+                _cast_param(param_key, parameters, filter_types[param_key])
     print(transform(parameters))
 
+def _cast_param(key, params, param_type):
+    if param_type == "int":
+        params[key] = int(params[key])
+    elif param_type == "bool":
+        params[key] = params[key] and params[key].lower() == "true"
+    return
 
 class SubCCompleter:
     def __init__(self, sc_type):
@@ -1320,9 +1337,18 @@ def azure_template_parameters():
     ).competer = FilesCompleter()
     argcomplete.autocomplete(parser)
     args = parser.parse_args()
-    template = json_load(open(args.template).read())
+    template = {}
+    if args.template.endswith(".bicep"):
+        process = Popen(["az", "bicep", "build", "--file", args.template, "--stdout"], stdout=PIPE, stderr=PIPE)
+        out, _ = process.communicate()
+        template = json.loads(out)
+    else:
+        template = json_load(open(args.template).read())
+    parameters = []
     if "parameters" in template and template["parameters"]:
-        print(",".join(template["parameters"].keys()))
+        for param in template["parameters"]:
+            parameters.append(f"{param}:{template['parameters'][param]['type']}")
+        print(",".join(parameters))
 
 
 def azure_location():
@@ -1335,11 +1361,11 @@ def azure_location():
 
 def resolve_location():
     if (
-        "AZURE_LOCATION" in environ
-        and environ["AZURE_LOCATION"]
-        and environ["AZURE_LOCATION"] != "default"
+        "AZURE_LOCATION" in os.environ
+        and os.environ["AZURE_LOCATION"]
+        and os.environ["AZURE_LOCATION"] != "default"
     ):
-        return environ["AZURE_LOCATION"]
+        return os.environ["AZURE_LOCATION"]
     else:
         parameters = load_parameters()
         if (
