@@ -40,6 +40,8 @@ usage() {
   echo "" >&2
   echo "Exports ndt parameters into component/cdk-name/variables.json, runs pre_deploy.sh in the" >&2
   echo "cdk project and runs cdk diff; cdk deploy for the same" >&2
+  echo "If pre_deploy.sh and post_deploy.sh exist and are executable in the subcompoent directory," >&2
+  echo "they will be executed before and after the deployment, respectively." >&2
   echo "" >&2
   echo "positional arguments:" >&2
   echo "  component   the component directory where the cdk directory is" >&2
