@@ -21,13 +21,19 @@ if [ -z "$DEPLOYTOOLS_VERSION" ]; then
   fi
 fi
 if [ -z "$MAVEN_VERSION" ]; then
-  MAVEN_VERSION=3.8.6
+  MAVEN_VERSION=3.8.7
 fi
 if [ -z "$PHANTOMJS_VERSION" ]; then
   PHANTOMJS_VERSION=2.1.1
 fi
 if [ -z "$NEXUS_VERSION" ]; then
-  NEXUS_VERSION=2.12.0-01
+  NEXUS_VERSION=2.15.1-02
+fi
+if [ -z "$NEXUS3_VERSION" ]; then
+  NEXUS3_VERSION=3.47.1-01
+fi
+if [ -z "$CARGO_PLUGIN_VERSION" ]; then
+  CARGO_PLUGIN_VERSION=0.0.6
 fi
 if [ -z "$ONEAGENT_VERSION" ]; then
   ONEAGENT_VERSION=1.215.163
@@ -36,11 +42,11 @@ if [ -z "$ACTIVEGATE_VERSION" ]; then
   ACTIVEGATE_VERSION=1.215.163
 fi
 if [ -z "$FLUTTER_VERSION" ]; then
-  FLUTTER_VERSION=3.0.4
-  FLUTTER_CSUM=be1dd08cb18504ddf6d435044fd5e162a4a420b8c48fe66a0002eefe6c58fa0a
+  FLUTTER_VERSION=3.7.3
+  FLUTTER_CSUM=7b3d2900ce0e367d73d85591d5d43a11f94a223278dd3220776b03a83e234865
 fi
 if [ -z "$LEIN_COMMIT" ]; then
-  LEIN_COMMIT=ef5ab97f058e8cb01e9c6a5a1cb6aa45c3b01d27 # 2.9.8
+  LEIN_COMMIT=64e02a842e7bb50edc9b8b35de1e2ef1fac090dd # 2.10.0
 fi
 
 # Make sure we get logging
@@ -49,10 +55,20 @@ if ! grep cloud-init-output.log /etc/cloud/cloud.cfg.d/05_logging.cfg > /dev/nul
 fi
 
 install_lein() {
-  wget -O /usr/bin/lein https://codeberg.org/leiningen/leiningen/raw/commit/ef5ab97f058e8cb01e9c6a5a1cb6aa45c3b01d27/bin/lein
+  wget -O /usr/bin/lein https://codeberg.org/leiningen/leiningen/raw/commit/$LEIN_COMMIT/bin/lein
   chmod 755 /usr/bin/lein
 }
 install_phantomjs() {
+  echo "############################################################################"
+  echo " PHANTOMJS IS DEPRECATED AND INSTALLATION IS NO LONGER SUPPORTED BY DEFAULT"
+  echo " IF YOU STILL NEED IT AND CANNOT MIGRATE TO E.G. HEADLESS CHROME AND YOU"
+  echo " UNDERSTAND THE IMPLICATIONS IF RUNNING OBSOLETE BROWSER SOFTWARE, YOU CAN"
+  echo " CHANGE install_phantomjs TO install_phantomjs_insecure"
+  echo " REMOVING PHANTOMJS IS STRONGLY RECOMMENDED HOWEVER."
+  echo "############################################################################"
+
+}
+install_phantomjs_insecure() {
   wget -O - https://bitbucket.org/ariya/phantomjs/downloads/phantomjs-$PHANTOMJS_VERSION-linux-x86_64.tar.bz2 | tar -xjvf -
   mv phantomjs-*/bin/phantomjs /usr/bin
   rm -rf phantomjs-*
@@ -104,9 +120,15 @@ MARKER
   sed -i 's/nexus-webapp-context-path=.*/nexus-webapp-context-path=\//' /opt/nexus/current/conf/nexus.properties
 }
 install_nexus3() {
-  wget -O - https://sonatype-download.global.ssl.fastly.net/repository/downloads-prod-group/3/nexus-$NEXUS3_VERSION-unix.tar.gz | tar -xzf - -C /opt/nexus
+  source $(n-include common_tools.sh)
+  add_gpg_key 0374CF2E8DD1BDFD
+  gpg_safe_download https://sonatype-download.global.ssl.fastly.net/repository/downloads-prod-group/3/nexus-$NEXUS3_VERSION-unix.tar.gz nexus3.tar.gz asc
+  mkdir -p /opt/nexus
+  tar -xzf nexus3.tar.gz -C /opt/nexus
   chown -R nexus:nexus /opt/nexus
+  rm -f nexus3.tar.gz nexus3.tar.gz.sig
   ln -snf /opt/nexus/nexus-* /opt/nexus/current
+  mkdir -p /opt/nexus/sonatype-work
   mv /opt/nexus/sonatype-work /opt/nexus/sonatype-work-initial
   cat > /usr/lib/systemd/system/nexus.service << MARKER
 [Unit]
@@ -123,6 +145,30 @@ Alias=nexus
 WantedBy=default.target
 MARKER
 }
+install_nexus3_cargo_plugin() {
+  add_gpg_key 80900DA1952D7C7968F3CFD98C79C4D0382A0E3A
+  gpg_safe_download https://repo1.maven.org/maven2/org/sonatype/nexus/plugins/nexus-repository-cargo/$CARGO_PLUGIN_VERSION/nexus-repository-cargo-$CARGO_PLUGIN_VERSION.jar nexus-repository-cargo-$CARGO_PLUGIN_VERSION.jar asc
+  mkdir -p /opt/nexus/current/system/org/sonatype/nexus/plugins/nexus-repository-cargo/$CARGO_PLUGIN_VERSION/
+  mv nexus-repository-cargo-$CARGO_PLUGIN_VERSION.jar /opt/nexus/current/system/org/sonatype/nexus/plugins/nexus-repository-cargo/$CARGO_PLUGIN_VERSION/
+
+  cat >> diff.xml << MARKER
+<diff xmlns:krf="http://karaf.apache.org/xmlns/features/v1.6.0">
+  <add sel="//krf:feature[@name='nexus-core-feature']">    <krf:feature prerequisite="false" dependency="false">nexus-repository-cargo</krf:feature>
+    </add>
+  <add sel="//krf:feature[@name='nexus-repository-maven']" pos="after">
+    <krf:feature name="nexus-repository-cargo" description="org.sonatype.nexus.plugins:nexus-repository-cargo" version="$CARGO_PLUGIN_VERSION">
+        <krf:details>org.sonatype.nexus.plugins:nexus-repository-cargo</krf:details>
+        <krf:bundle>mvn:org.sonatype.nexus.plugins/nexus-repository-cargo/$CARGO_PLUGIN_VERSION</krf:bundle>
+    </krf:feature></add>
+</diff>
+MARKER
+  add_gpg_key 379CE192D401AB61
+  gpg_safe_download https://search.maven.org/remotecontent?filepath=com/github/dnault/xml-patch/0.3.1/xml-patch-0.3.1.jar xml-patch.jar asc
+  java -jar xml-patch.jar /opt/nexus/current/system/org/sonatype/nexus/assemblies/nexus-core-feature/*/nexus-core-feature-*-features.xml diff.xml temp.xml
+  mv -f temp.xml /opt/nexus/current/system/org/sonatype/nexus/assemblies/nexus-core-feature/*/nexus-core-feature-*-features.xml
+  chown nexus:nexus /opt/nexus/current/system/org/sonatype/nexus/assemblies/nexus-core-feature/*/nexus-core-feature-*-features.xml
+  rm -f xml-patch.jar diff.xml
+}
 install_fail2ban() {
   yum update -y selinux-policy*
   mkdir -p /var/run/fail2ban
