@@ -1,19 +1,19 @@
 import argparse
+import json
 import os
 import re
-import json
 from datetime import datetime
 from os import R_OK, access
-from os.path import exists, expanduser, isfile, join, isdir
+from os.path import exists, expanduser, isdir, isfile, join
 
 import argcomplete
 from argcomplete.completers import ChoicesCompleter
 from dateutil.parser import parse
 from dateutil.tz import tzutc
 
+from n_utils.az_util import az_select_subscription
 from n_utils.bw_util import get_bwentry
 from n_utils.lp_util import get_lpentry
-from n_utils.az_util import az_select_subscription
 from n_utils.mfa_utils import mfa_generate_code
 
 
@@ -350,8 +350,9 @@ def update_profile_conf(profile, creds):
         parser = ConfigParser()
         with open(config, "r") as conffile:
             parser.read_file(conffile)
-            if profile_section not in parser.sections():
-                parser.add_section(profile_section)
+            if profile_section in parser.sections():
+                parser.remove_section(profile_section)
+            parser.add_section(profile_section)
             for key in creds:
                 parser.set(profile_section, key, creds[key])
     with open(config, "w") as conffile:
@@ -391,7 +392,7 @@ def store_bw_profile(bw_entry_name):
 
 
 def cli_store_bw_profile():
-    """Fetches a Bitwarde entry and if it contains a definition of a aws credentials, stores it in aws cli
+    """Fetches a Bitwarden entry and if it contains a definition of a aws credentials, stores it in aws cli
     configuration. Namely the entry needs to define the extra fields aws_access_key_id, aws_secret_access_key
     and profile_name"""
     parser = argparse.ArgumentParser(description=cli_store_bw_profile.__doc__)
